@@ -14,11 +14,10 @@ MORSE_CODE_DICT = { 'A':'.-', 'B':'-...',
 					'?':'..--..', '/':'-..-.', '-':'-....-',
 					'(':'-.--.', ')':'-.--.-'}
 def encrypt(message):
-  message = message.upper()
 	cipher = ''
 	for letter in message:
 		if letter != ' ':
-			cipher += MORSE_CODE_DICT[letter] + ' '
+			cipher += MORSE_CODE_DICT[letter.upper()] + ' '
 		else:
 			cipher += ' '
 	return cipher
